/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views.ErrorViewFX;

import java.util.Map;

import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeContentProviderBase;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeTableUIProviderBase;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeTableViewer;
import org.fortiss.tooling.common.ui.javafx.layout.CompositeFXControllerBase;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity;

import javafx.fxml.FXML;
import javafx.scene.Node;
import javafx.scene.control.CheckBox;
import javafx.scene.layout.BorderPane;

/**
 * 
 * Let's say hello to the world.
 * 
 * 
 * 
 * Controller class for the "Hello world!" view. References the FXML layout and contains all control
 * 
 * logic.
 * 
 * 
 * 
 * @author abid
 * 
 */

public class ErrorViewFXLayoutController extends CompositeFXControllerBase<Node, Node> {

	/** Debug Button */
	@FXML
	private CheckBox debugBtn;
	/** Info Button */
	@FXML
	private CheckBox infoBtn;
	/** Warning Button */
	@FXML
	private CheckBox warningBtn;
	/** Error Button */
	@FXML
	private CheckBox errorBtn;
	/** Fatal Button */
	@FXML
	private CheckBox fatalBtn;
	/** Border Pane for the tree table */
	@FXML
	private BorderPane pane;

	/** Toggle State */
	private Map<ESeverity, Boolean> toggleState;

	/**
	 * @param toggleState
	 */
	public ErrorViewFXLayoutController(Map<ESeverity, Boolean> toggleState) {
		this.toggleState = toggleState;
	}

	/** Called when debug checkbox is pushed. */
	public void onDebugBtn() {

	}

	/** Called when info checkbox is pushed. */
	public void onInfoBtn() {

	}

	/** Called when warning checkbox is pushed. */
	public void onWarningBtn() {

	}

	/** Called when error checkbox is pushed. */
	public void onErrorBtn() {

	}

	/** Called when fatal checkbox is pushed. */
	public void onFatalBtn() {

	}

	@Override
	public String getFXMLLocation() {
		return "ErrorViewFXLayout.fxml";
	}

	/** {@inheritDoc} */
	@Override
	public void initialize() {
		DynamicTreeContentProviderBase<Object> contentProvider = new MarkerViewFXContentProvider();
		DynamicTreeTableUIProviderBase<Object> uiProvider = new MarkerViewFXUIProvider();

		DynamicTreeTableViewer<Object> treeTable = new DynamicTreeTableViewer<Object>(new Object(),
				false, 2, contentProvider, uiProvider);

		treeTable.addColumn("Severity", 80);
		treeTable.addColumn("Element", 80);
		treeTable.addColumn("Explanation", 80);
		treeTable.addColumn("Project", 80);

		pane.setCenter(treeTable.getControl());
		pane.layout();
	}
}
