/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views.ErrorViewFX;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeTableUIProviderBase;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.IPersistencyService;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;

/**
 * 
 * @author abid
 */
public class MarkerViewFXUIProvider extends DynamicTreeTableUIProviderBase<Object> {

	/** {@inheritDoc} */
	@Override
	public String getLabel(Object element, int column) {

		// column for ESevertiy Type Error, Warning etc....
		if(column == 0) {
			return "";
			// return getModelElementHandlerName(element);
		}
		// column for source element
		if(column == 1) {
			if(element instanceof IConstraintViolation) {
				IConstraintViolation<? extends EObject> violation =
						(IConstraintViolation<? extends EObject>)element;
				IModelElementHandlerService hs = IModelElementHandlerService.getInstance();
				IModelElementHandler<EObject> handler =
						hs.getModelElementHandler(violation.getSource());
				if(handler != null) {
					return handler.getName(violation.getSource());
				} else {
					return "";
				}
			}
			// column for the Explanation Column
			else if(column == 2) {
				if(element instanceof IConstraintViolation) {
					IConstraintViolation<? extends EObject> violation =
							(IConstraintViolation<? extends EObject>)element;
					return violation.getExplanation();
				} else {
					return "";
				}
			}
			// column for the Project Column
			else if(column == 3) {

				if(element instanceof IConstraintViolation) {
					IConstraintViolation<? extends EObject> violation =
							(IConstraintViolation<? extends EObject>)element;
					IPersistencyService ps = IPersistencyService.getInstance();
					ITopLevelElement topElement = ps.getTopLevelElementFor(violation.getSource());

					IModelElementHandler<EObject> handler = null;
					EObject rootElement = null;
					if(topElement != null) {
						rootElement = topElement.getRootModelElement();

						IModelElementHandlerService hs = IModelElementHandlerService.getInstance();
						handler = hs.getModelElementHandler(rootElement);
					}
					if(handler != null) {
						return handler.getName(rootElement);
					} else {
						return "";
					}
				} else {
					return "";
				}
			}
		}
		return "";
	}

}
