/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views;

import static org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity.DEBUG;
import static org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity.ERROR;
import static org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity.FATAL;
import static org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity.INFO;
import static org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity.WARNING;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.jface.viewers.CellLabelProvider;
import org.eclipse.jface.viewers.ColumnViewerToolTipSupport;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.ViewerCell;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.part.ViewPart;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;
import org.fortiss.tooling.kernel.service.IPersistencyService;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.service.IMarkerService;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;

/**
 * {@link ViewPart} for the marker display.
 * 
 * @author hoelzl
 */
@Deprecated
public class MarkerViewPart extends ViewPart {

	/** Stores the toggle state of for each severity level. */
	private Map<ESeverity, Boolean> toggleState = new HashMap<ESeverity, Boolean>();

	/** GUI builder viewer instance. */
	private MarkerViewerGUI gui;

	/** Toggle expert severity filter actions. */
	private Action[] toggleSeverityFilterAction = new Action[5];

	/** Constructor. */
	public MarkerViewPart() {
		// ((MarkerService)IMarkerService.getInstance()).setMarkerViewPart(this);
		toggleState.put(DEBUG, false);
		toggleState.put(INFO, false);
		toggleState.put(WARNING, true);
		toggleState.put(ERROR, true);
		toggleState.put(FATAL, false);
	}

	/** {@inheritDoc} */
	@Override
	@SuppressWarnings("unchecked")
	public void createPartControl(Composite parent) {
		parent.setLayout(new FillLayout());
		gui = new MarkerViewerGUI(parent, SWT.NONE);
		gui.getTreeViewer().setContentProvider(new MarkerViewContentProvider(this));
		gui.getSeverityColumn().setLabelProvider(new CellLabelProvider() {
			@Override
			public void update(ViewerCell cell) {
				if(cell.getElement() instanceof ESeverity) {
					final ESeverity severity = (ESeverity)cell.getElement();
					cell.setText(severity.toString());
					cell.setImage(IMarkerService.getInstance().getSharedImageFor(severity, false));
				} else {
					cell.setText("");
				}
			}
		});
		gui.getElementColumn().setLabelProvider(new CellLabelProvider() {
			@Override
			public void update(ViewerCell cell) {
				if(cell.getElement() instanceof IConstraintViolation) {
					IConstraintViolation<? extends EObject> violation =
							(IConstraintViolation<? extends EObject>)cell.getElement();
					IModelElementHandlerService hs = IModelElementHandlerService.getInstance();
					IModelElementHandler<EObject> handler =
							hs.getModelElementHandler(violation.getSource());
					cell.setText(handler != null ? handler.getName(violation.getSource()) : "");
				} else {
					cell.setText("");
				}
			}
		});
		gui.getExplanationColumn().setLabelProvider(new CellLabelProvider() {
			@Override
			public void update(ViewerCell cell) {
				if(cell.getElement() instanceof IConstraintViolation) {
					IConstraintViolation<? extends EObject> violation =
							(IConstraintViolation<? extends EObject>)cell.getElement();
					cell.setText(violation.getExplanation());
				} else {
					cell.setText("");
				}
			}
		});

		gui.getProjectColumn().setLabelProvider(new CellLabelProvider() {
			@Override
			public void update(ViewerCell cell) {
				if(cell.getElement() instanceof IConstraintViolation) {
					IConstraintViolation<? extends EObject> violation =
							(IConstraintViolation<? extends EObject>)cell.getElement();
					IPersistencyService ps = IPersistencyService.getInstance();
					ITopLevelElement topElement = ps.getTopLevelElementFor(violation.getSource());

					IModelElementHandler<EObject> handler = null;
					EObject rootElement = null;
					if(topElement != null) {
						rootElement = topElement.getRootModelElement();

						IModelElementHandlerService hs = IModelElementHandlerService.getInstance();
						handler = hs.getModelElementHandler(rootElement);
					}
					cell.setText(handler != null ? handler.getName(rootElement) : "");
				} else {
					cell.setText("");
				}
			}
		});

		ColumnViewerToolTipSupport.enableFor(gui.getElementColumn().getViewer());
		ColumnViewerToolTipSupport.enableFor(gui.getExplanationColumn().getViewer());
		ColumnViewerToolTipSupport.enableFor(gui.getProjectColumn().getViewer());

		gui.getTreeViewer().addDoubleClickListener(new DoubleClick(true) {
			/** {@inheritDoc} */
			@Override
			protected EObject getDoubleClickedElement(IStructuredSelection selection) {
				if(selection.getFirstElement() instanceof IConstraintViolation) {
					return ((IConstraintViolation<EObject>)selection.getFirstElement())
							.getContainer();
				}
				return super.getDoubleClickedElement(selection);
			}
		});
		gui.getTreeViewer().setInput(IMarkerService.getInstance());

		createToggleActions();
	}

	/** {@inheritDoc} */
	@Override
	public void setFocus() {
		gui.getTreeViewer().getControl().setFocus();
	}

	/** Refreshes the view. Needs to be called on UI thread. */
	public void refresh() {
		if(!gui.getTreeViewer().getControl().isDisposed()) {
			gui.getTreeViewer().refresh();
		}
	}

	/** Returns toggleState. */
	/* package */Boolean getToggleState(ESeverity sev) {
		return toggleState.get(sev);
	}

	/** Creates the toggle actions. */
	private void createToggleActions() {
		toggleSeverityFilterAction[0] =
				new SeverityFilterAction("D", "Toggle DEBUG Messages", DEBUG);
		toggleSeverityFilterAction[1] = new SeverityFilterAction("I", "Toggle INFO Messages", INFO);
		toggleSeverityFilterAction[2] =
				new SeverityFilterAction("W", "Toggle WARNING Messages", WARNING);
		toggleSeverityFilterAction[3] =
				new SeverityFilterAction("E", "Toggle ERROR Messages", ERROR);
		toggleSeverityFilterAction[4] =
				new SeverityFilterAction("F", "Toggle FATAL Messages", FATAL);

		IToolBarManager toolBarManager = getViewSite().getActionBars().getToolBarManager();
		Separator additionsSeperator = new Separator("additions");
		additionsSeperator.setVisible(true);
		toolBarManager.add(additionsSeperator);
		for(int i = 0; i < toggleSeverityFilterAction.length; i++) {
			toolBarManager.insertAfter("additions", toggleSeverityFilterAction[i]);
		}
	}

	/** Action for severity filter toggle. */
	private class SeverityFilterAction extends Action {
		/** Stores the severity level this action toggles. */
		private final ESeverity severity;

		/** Constructor. */
		public SeverityFilterAction(String name, String tooltip, ESeverity severity) {
			super(name, SWT.TOGGLE);
			this.severity = severity;
			setToolTipText(tooltip);
			setChecked(toggleState.get(severity));
			setImageDescriptor(IMarkerService.getInstance().getImageFor(severity, false));
		}

		/** {@inheritDoc} */
		@Override
		public void run() {
			// invert state
			toggleState.put(severity, !toggleState.get(severity));
			refresh();
		}
	}
}
